@@ -7,14 +7,9 @@ LOCAL = R6::R6Class("LOCAL",
     inherit = QSys,
 
     public = list(
-        initialize = function(..., data=NULL) {
-            super$initialize(..., data=data)
-        },
-
-        set_common_data = function(...) {
-        },
-
-        submit_jobs = function(..., verbose=TRUE) {
+        initialize = function(addr="unused", n_jobs=0, ..., log_worker=FALSE,
+                              log_file=NULL, verbose=TRUE) {
+            super$initialize(addr=addr, ...)
             if (verbose)
                 message("Running sequentially ('LOCAL') ...")
         },
